/**
 * Canvas.c - Create a canvas (ROVLib speak for window)
 */

/* Include 4 standard C header files */
#include <stdlib.h>
#include <string.h>
#include <stdio.h>
#include <ctype.h>

/* Include the RISC OS kernel header file */
#include "kernel.h"

/* Include the ROVLib header files */
#include "main.h"
#include "canvas.h"
#include "baricon.h"
#include "extras.h"

/* Prototype the click function */
void click_iconbar(int icn);

/* Prototype the canvas close function */
void close_canvas(canvas c);

/* A variable to hold the canvas */
static canvas c;

int main(int argc, char **argv) {
  /* Initialise the ROVLib system */
  main_init("Canvas test");

  /* Initialise the ROVLib canvas core */
  canvas_init();

  /* Create the canvas */
  c = canvas_create(640, 480, "An example canvas");

  /* Add the close handler for the canvas */
  canvas_addhandler(c, CANVAS_CLOSEHANDLER, close_canvas);

  /* Make the canvas as a window */
  canvas_make(c);

  /* Create an icon on the icon bar */
  baricon("file_ff8", click_iconbar);

  /* Open the canvas in the centre of the screen */
  canvas_opencentre(c);

  /* Poll forever (or at least until told to quit!) */
  main_poll();
}

/* Actually perform the click function */
void click_iconbar(int icn) {
  canvas_reopen(c);
}

/* Actually perform the close function */
void close_canvas(canvas c) {
  exit(0);
}
